==> bee-ui-0.0.44-20170922182640.tgz: package/README.md <==
# BeeUI
A React NATIVE UI Libary.

`issues`规范:
- `feature` 功能 `bug` 故障
- 优先级: `p0`: 日清 `p1`: 一周内 `p2`: 二周 `p3`: 月内
### 状态: `todo` 待开发, `doing` 进行中, `test` 待测试, `done` 已完成

| 组件名称 | 描述 | 状态 | issues |
|---------|------|------|----|
| [Calender](./docs/Calender.md) | 日历组件 | `done` | -- |
| [Chart](./docs/Chart.md) | 柱状图 | `done` | -- |
| [Flex](./docs/Flex.md) | Flex 布局 | `done` | -- |
| [Grid](./docs/Grid.md) | Grid 布局 | `done` | -- |
| [Gallery](./docs/Gallery.md) | 轮播图 | `done` | -- |
| [Overlay](./docs/Overlay.md) | 蒙层 | `done` | -- |
| [Picker](./docs/Picker.md) | 选择器, 目前只支持单选 | `done` | -- |
| [Sheet](./docs/Sheet.md) | 下方弹出框 | `done` | -- |
| [TabBar](./docs/TabBar.md) | Tab切换栏 | `done` | -- |
| [TabScene](./docs/TabScene.md) | Tab内容  | `done` | -- |
| [Tools](./docs/Tools.md) | 工具模块,px转dpi,控制设备字体 | `done` | -- |
| [Calender](./docs/Calender.md) | 日历控件 | `done` | -- |

### 依赖
- 全局依赖: `npm install -g exp` 以及 [Expo XDE](expo.io);

### 启动说明
- 准备工作：
  - 安装依赖：`npm i`
  - 设置淘宝镜像源：`npm config set registry https://registry.npm.taobao.org`
- 启动项目：
  - 苹果：`npm run ios`
  - 安卓：`npm run android`
- 其他：
  - 发布：`npm run deploy <password>`
  - 代码规范：`npm run lint`

### 常见问题
- 项目无法启动：
  - 尝试重新安装依赖：`rm package-lock.json && rm -rf node_modules && npm i`
  - 还不行的话试试：`rm -rf $TMPDIR/react-*`
- `Git:.git/hooks/pre-commit: line 2: ./node_modules/pre-commit/hook: No such file or directory`
  1. 打开目录：`.git/hooks`
  2. 编辑文件：`pre-commit`
  3. 删除第二行：`./node_modules/pre-commit/hook`
- `jsx-a11y/href-no-hash`
  1. 查看全局安装的依赖是否包含 **eslint**：`npm list -g --depth 0`
  2. 如果存在则需要全局安装 **eslint-plugin-jsx-a11y**：`npm i -g eslint-plugin-jsx-a11y`

==> bee-ui-0.0.45-20170923173436.tgz: package/README.md <==
# BeeUI
A React NATIVE UI Libary.

`issues`规范:
- `feature` 功能 `bug` 故障
- 优先级: `p0`: 日清 `p1`: 一周内 `p2`: 二周 `p3`: 月内
### 状态: `todo` 待开发, `doing` 进行中, `test` 待测试, `done` 已完成

| 组件名称 | 描述 | 状态 | issues |
|---------|------|------|----|
| [Calender](./docs/Calender.md) | 日历组件 | `done` | -- |
| [Chart](./docs/Chart.md) | 柱状图 | `done` | -- |
| [Flex](./docs/Flex.md) | Flex 布局 | `done` | -- |
| [Grid](./docs/Grid.md) | Grid 布局 | `done` | -- |
| [Gallery](./docs/Gallery.md) | 轮播图 | `done` | -- |
| [Overlay](./docs/Overlay.md) | 蒙层 | `done` | -- |
| [Picker](./docs/Picker.md) | 选择器, 目前只支持单选 | `done` | -- |
| [Sheet](./docs/Sheet.md) | 下方弹出框 | `done` | -- |
| [TabBar](./docs/TabBar.md) | Tab切换栏 | `done` | -- |
| [TabScene](./docs/TabScene.md) | Tab内容  | `done` | -- |
| [Tools](./docs/Tools.md) | 工具模块,px转dpi,控制设备字体 | `done` | -- |
| [Calender](./docs/Calender.md) | 单选日历控件 | `done` | -- |
| [CalenderPick](./docs/CalenderPick.md) | 多选日历控件 | `done` | -- |

### 依赖
- 全局依赖: `npm install -g exp` 以及 [Expo XDE](expo.io);

### 启动说明
- 准备工作：
  - 安装依赖：`npm i`
  - 设置淘宝镜像源：`npm config set registry https://registry.npm.taobao.org`
- 启动项目：
  - 苹果：`npm run ios`
  - 安卓：`npm run android`
- 其他：
  - 发布：`npm run deploy <password>`
  - 代码规范：`npm run lint`

### 常见问题
- 项目无法启动：
  - 尝试重新安装依赖：`rm package-lock.json && rm -rf node_modules && npm i`
  - 还不行的话试试：`rm -rf $TMPDIR/react-*`
- `Git:.git/hooks/pre-commit: line 2: ./node_modules/pre-commit/hook: No such file or directory`
  1. 打开目录：`.git/hooks`
  2. 编辑文件：`pre-commit`
  3. 删除第二行：`./node_modules/pre-commit/hook`
- `jsx-a11y/href-no-hash`
  1. 查看全局安装的依赖是否包含 **eslint**：`npm list -g --depth 0`
  2. 如果存在则需要全局安装 **eslint-plugin-jsx-a11y**：`npm i -g eslint-plugin-jsx-a11y`
